@@ -41,6 +41,8 @@
 
 #define KGLOBALACCEL_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
+#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
+
 /* Take any defaults from group settings */
 #if !defined(KGLOBALACCEL_NO_DEPRECATED) && !defined(KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -84,7 +86,7 @@
 #define KGLOBALACCEL_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KGLOBALACCEL_NO_DEPRECATED
-#  define KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57200
+#  define KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54600
 #endif
 #ifdef KGLOBALACCEL_NO_DEPRECATED_WARNINGS
 #  define KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +96,7 @@
 #  ifdef KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE 0x57200
+#    define KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE 0x54600
 #  endif
 #endif
 
@@ -103,7 +105,7 @@
 #endif
 
 #ifdef KGLOBALACCEL_DEPRECATED
-#  define KGLOBALACCEL_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KGLOBALACCEL_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KGLOBALACCEL_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KGLOBALACCEL_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
@@ -125,28 +127,8 @@
 #else
 #  define KGLOBALACCEL_DEPRECATED_VERSION_5_9(text)
 #endif
-
-#if KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE >= 0x55a00
-#  define KGLOBALACCEL_DEPRECATED_VERSION_5_90(text) KGLOBALACCEL_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KGLOBALACCEL_DEPRECATED_VERSION_5_90(text)
-#endif
-
-#if KGLOBALACCEL_DEPRECATED_WARNINGS_SINCE >= 0x56600
-#  define KGLOBALACCEL_DEPRECATED_VERSION_5_102(text) KGLOBALACCEL_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KGLOBALACCEL_DEPRECATED_VERSION_5_102(text)
-#endif
 #define KGLOBALACCEL_DEPRECATED_VERSION_4(minor, text)      KGLOBALACCEL_DEPRECATED_VERSION_4_##minor(text)
 #define KGLOBALACCEL_DEPRECATED_VERSION_5(minor, text)      KGLOBALACCEL_DEPRECATED_VERSION_5_##minor(text)
 #define KGLOBALACCEL_DEPRECATED_VERSION(major, minor, text) KGLOBALACCEL_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
-#define KGLOBALACCEL_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KGLOBALACCEL_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
-#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
-#  define KGLOBALACCEL_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KGLOBALACCEL_DEPRECATED_VERSION(major, minor, text)
-#  define KGLOBALACCEL_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KGLOBALACCEL_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
-#else
-#  define KGLOBALACCEL_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
-#  define KGLOBALACCEL_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
-#endif
 
 #endif /* KGLOBALACCEL_EXPORT_H */
